        // Implementation of the StopWatch interface.
import java.util.*;

class Timer implements StopWatch {
    public Timer(){
        // Make sure everything is reset to start with.
        reset();
    }

    public void reset(){
        setState(RESET);
        elapsedTime = new Date(0);
    }

    public void start(){
        if(getState() == RESET){
            startTime = new Date();
            setState(RUNNING);
        }
    }

    public void stop(){
        if(getState() == RUNNING){
            // Calculate the elapsed time at this point.
            recordElapsedTime();
            setState(STOPPED);
        }
        else if(getState() == SUSPENDED){
            setState(STOPPED);
        }
        else{
            // Inappropriate action.
        }
    }

    public void suspend(){
        if(getState() == RUNNING){
            recordElapsedTime();
            setState(SUSPENDED);
        }
    }

    public void resume(){
        if(getState() == SUSPENDED){
            // Get the resumption time.
            startTime = new Date();
            setState(RUNNING);
        }
    }

    public long getElapsedTime(){
        // We must calculate how much time has passed since the
        // elapsed time was last calculated.
        long increment = 0;
        if(getState() == RUNNING){
            Date now = new Date();
            increment = now.getTime()-startTime.getTime();
        }
        return elapsedTime.getTime() + increment;
    }

    public int getState(){
        return state;
    }

    private void setState(int s){
        state = s;
    }

        // Calculate how much has elapsed to this point.
    private void recordElapsedTime(){
        Date now = new Date();
        // Find out how much time has passed since the last
        // startTime.
        long increment = now.getTime()-startTime.getTime();
        // Add it in to what has elapsed so far.
        long totalTime = elapsedTime.getTime()+increment;
        elapsedTime.setTime(totalTime);
    }

    // Current state: RESET, RUNNING, SUSPENDED, STOPPED.
    private int state = RESET;
    // Keep track of the most recent start time and
    // how much time has elapsed in the preceding periods.
    private Date startTime, elapsedTime;
}
