        /* Demonstration rig for the VariableController class.
         * Create an arbitrary number of VariableControllers and
         * randomly turn them on and off.
         * A GUI provides a visualisation via the Heater class.
         */
class VariableControllerDemo {
    public void run(){
        while(true){
            // Select a random controller.
            final VariableController c = randomController();
            // Change its state if possible.
            if(turnItOff()){
                if(c.isOn()){
                    c.switchOff();
                }
            }
            else{
                c.switchOn();
                // Set the temperature to a random level.
                c.setLevel(randomLevel());
            }
            // Pause a little.
            delay();
        }
    }

        // Randomly decide whether to turn a controller off.
    protected boolean turnItOff(){
        return Math.random() < 0.5;
    }

        // Generate an in-range random level to which the
        // controller should be set.
    protected int randomLevel(){
        int level = (int) (Math.abs(Math.random()) * 
            (VariableController.MaxLevel-VariableController.MinLevel+1));
        return VariableController.MinLevel+level;
    }

        // Randomly select a controller to adjust
    private VariableController randomController(){
        final VariableController[] controllers = getControllers();
        // Which controller to select.
        int which = (int) (Math.random()*controllers.length);
        return controllers[which];
    }

    protected void delay(){
        try{
            // Sleep for 1 second.
            Thread.sleep(1000);
        }
        catch(InterruptedException e){
        }
    }

    protected VariableController[] getControllers(){
        return controllers;
    }

    // Create an arbitrary number of VariableController objects
    // to be manipulated.
    // Initialise the individual controller objects.
    private final VariableController[] controllers;
    {
        // How many controllers to create.
        final int numControllers = 5;
        controllers = new VariableController[numControllers];
        for(int i = 0; i < numControllers; i++){
            controllers[i] = new VariableController();
        }
    }
}
