import javax.swing.*;
import java.awt.*;

    /* Provide a slightly different view of the RangeCounts data
     * from that of the super class.
     * Show cumulative bars, rather than individual bars.
     */
class SwingCumulativeChart extends SwingBarChart {
    public SwingCumulativeChart(RangeCounts data){
        super(data);
    }

        // Override this method to create an array of cumulative counts.
    protected void drawBars(){
        // Draw the bars directly from the counts.
        final int[] counts = getData().getCounts();
        final int numCounts = counts.length;
        int[] cumulative = new int[numCounts];

        cumulative[0] = counts[0];
        for(int i = 1; i < numCounts; i++){
            cumulative[i] = cumulative[i-1]+counts[i];
        }
        drawBarsFromData(cumulative);
    }

        // Make some labels up based upon the cumulative range of each
        // bar.
    protected String[] getDefaultBarLabels(){
        RangeCounts data = getData();
        String[] labels = null;
        if(data != null){
            final int unitsPerBar = data.getUnitsPerBar();
            final int numBars = data.numCounts();
            // The ends of the range.
            final int min = data.getMin();
            int max = min+unitsPerBar-1;
            labels = new String[numBars];
            for(int barNumber = 0; barNumber < numBars; barNumber++){
                labels[barNumber] = min+".."+max;
                max += unitsPerBar;
            }
        }
        return labels;
    }
}
